# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project adheres to [Semantic Version](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.1] - 2024-06-24
### Fixed
- `No module named build` when running scripts/build_package.sh
- `twine: command not found` when running scripts/upload_package.sh

## [0.2.0] - 2024-06-24
### Added
- scripts to automate package management.
- scripts to automate docker management.
- automated release to pypi in cd.
- automated release to docker hub in cd.

## [0.1.0] - 2024-06-23
### Added
- Init release.